<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package orabel
 */

?>
<!doctype html>
<html <?php language_attributes(); ?> class="is-preload">
<head>
	<!-- Meta Data -->
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta http-equiv="X-UA-Compatible" content="IE=edge">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
	<?php wp_body_open(); ?>

	<div class="orb-wrapper">
		<!-- page loader -->
		<div class="orb-loader-frame">
			<div class="orb-loader">
				<div class="orb-deco-1">
					<div class="orb-prog"></div>
				</div>
				<div class="orb-deco-2">
					<div class="orb-spiner"></div>
				</div>
			</div>
		</div>
		<!-- page loader end -->

		<div id="orb-dynamic-content" class="transition-fade">

			<?php
			$no_scroll = get_field( 'no_scroll' );
			$frame_type = 'scroll';
			if ( $no_scroll ) : $frame_type = 'page'; endif;
			?>

			<div class="orb-<?php echo esc_attr( $frame_type ); ?>-frame">

				<div class="orb-top-bar-frame">
					<div class="orb-content orb-top-bar">
						<?php
			      $header_template = get_field( 'header_template', 'option' );

			      if ( $header_template ) :
			        $args = array( 'post_type' => 'hf_templates', 'p' => $header_template );
			        $loop = new WP_Query( $args );
			        while ( $loop->have_posts() ) : $loop->the_post();
			          the_content();
			        endwhile; wp_reset_postdata();
			      else :
			      ?>

						<a href="<?php echo esc_url( home_url() ); ?>" class="orb-logo-frame">
							<span class="logotype__title"><?php echo esc_html( bloginfo('name') ); ?></span>
	            <span class="logotype__sub"><?php echo esc_html( bloginfo('description') ); ?></span>
						</a>
						<div class="orb-right-side">
							<div class="orb-menu-frame">
								<?php
		            if ( has_nav_menu( 'primary' ) ) :
		              wp_nav_menu( array(
		                'theme_location' => 'primary',
		                'container' => 'nav',
		                'container_class' => 'orb-menu-nav',
		                'menu_class' => 'orb-menu',
		                'walker' => new Orabel_Topmenu_Walker(),
		              ) );
		            endif; ?>
							</div>
						</div>
						<div class="orb-menu-btn">
							<span></span>
						</div>
						<?php endif; ?>
					</div>
				</div>
