<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package orabel
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function orabel_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	// Add a class of default layout
	$hf = get_field( 'header_template', 'option' );
	if ( ! $hf ) {
		$classes[] = 'default-layout';
	}
	if ( ( in_array( 'archive', $classes ) || in_array( 'search', $classes ) ) && ! in_array( 'default-layout', $classes ) ) {
		$classes[] = 'default-layout';
	}

	// Add a class of header or footer template
	$post_type = get_post_type();
	$hf_type = get_field( 'type' );
	if ( $post_type  == 'hf_templates' ) {
		$classes[] = 'hf-type-' . $hf_type;
	}

	return $classes;
}
add_filter( 'body_class', 'orabel_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function orabel_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'orabel_pingback_header' );
